==> jc-1.4.5.tar.gz: org/omg/CORBA/UserException.c <==
// public class org.omg.CORBA.UserException

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8fde9509a3d1aba7 org_omg_CORBA_IDLEntity
// @dep_class ba1af03772fd0b08 org_omg_CORBA_UserException

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_omg_CORBA_IDLEntity
// @dep_header org_omg_CORBA_UserException

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/omg/CORBA/IDLEntity.h"
#include "org/omg/CORBA/UserException.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_org_omg_CORBA_UserException$initial_value$serialVersionUID = _JC_JLONG(-6594940734566091244);
static _jc_field _jc_org_omg_CORBA_UserException$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_org_omg_CORBA_UserException$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_org_omg_CORBA_UserException$fields_struct, serialVersionUID),
	.initial_value=	&_jc_org_omg_CORBA_UserException$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_org_omg_CORBA_UserException$fields[] = {
	&_jc_org_omg_CORBA_UserException$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_org_omg_CORBA_UserException$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_org_omg_CORBA_UserException$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_org_omg_CORBA_UserException$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_org_omg_CORBA_UserException$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_omg_CORBA_UserException$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_org_omg_CORBA_UserException$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_omg_CORBA_UserException$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_omg_CORBA_UserException, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_org_omg_CORBA_UserException$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_org_omg_CORBA_UserException$object *this)
{
	struct _jc_org_omg_CORBA_UserException$object *r0;
	struct _jc_java_lang_String$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = _JC_NULL;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	_JC_INVOKE_VIRTUAL(env, java_lang_Throwable, fillInStackTrace$6204b72985f9038d, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r1;
	_JC_LINE_NUMBER(62);				// 0
	return;
}

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_org_omg_CORBA_UserException$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_org_omg_CORBA_UserException$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_org_omg_CORBA_UserException$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_org_omg_CORBA_UserException$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_org_omg_CORBA_UserException$type,
	.param_types=		&_jc_org_omg_CORBA_UserException$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_omg_CORBA_UserException$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_org_omg_CORBA_UserException$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_omg_CORBA_UserException$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_omg_CORBA_UserException, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_org_omg_CORBA_UserException$method$_init$c31b894660454d13(_jc_env *const env, _jc_org_omg_CORBA_UserException$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_org_omg_CORBA_UserException$object *r0;
	struct _jc_java_lang_String$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	_JC_INVOKE_VIRTUAL(env, java_lang_Throwable, fillInStackTrace$6204b72985f9038d, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r1;
	_JC_LINE_NUMBER(71);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_omg_CORBA_UserException$methods[] = {
	&_jc_org_omg_CORBA_UserException$method_info$_init$52f4ad9f2989aeee,
	&_jc_org_omg_CORBA_UserException$method_info$_init$c31b894660454d13
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_org_omg_CORBA_UserException$fields_struct _jc_org_omg_CORBA_UserException$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_omg_CORBA_UserException$interfaces[] = {
	&_jc_org_omg_CORBA_IDLEntity$type,
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_8[] = {
	&_jc_org_omg_CORBA_UserException$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_30[] = {
	&_jc_java_lang_Throwable$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_39[] = {
	&_jc_org_omg_CORBA_IDLEntity$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_87[] = {
	&_jc_java_lang_Exception$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_omg_CORBA_UserException$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[8]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_8,
	[30]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_30,
	[39]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_39,
	[65]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_65,
	[87]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_87,
	[101]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_omg_CORBA_UserException$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "org/omg/CORBA/IDLEntity",	_JC_JLONG(0x8fde9509a3d1aba7) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_omg_CORBA_UserException$vtype _jc_org_omg_CORBA_UserException$type = {
    .type= {
	.name=			"org/omg/CORBA/UserException",
	.superclass=		&_jc_java_lang_Exception$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_omg_CORBA_UserException$interfaces) / sizeof(*_jc_org_omg_CORBA_UserException$interfaces),
	.interfaces=		_jc_org_omg_CORBA_UserException$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		24,
		.hash=			_JC_JLONG(0xba1af03772fd0b08),
		.source_file=		"UserException.java",
		.instance_size=		sizeof(_jc_org_omg_CORBA_UserException$refs) + sizeof(_jc_org_omg_CORBA_UserException$object),
		.num_virtual_refs=	4,
		.num_fields=		sizeof(_jc_org_omg_CORBA_UserException$fields) / sizeof(*_jc_org_omg_CORBA_UserException$fields),
		.fields=		_jc_org_omg_CORBA_UserException$fields,
		.num_methods=		sizeof(_jc_org_omg_CORBA_UserException$methods) / sizeof(*_jc_org_omg_CORBA_UserException$methods),
		.methods=		_jc_org_omg_CORBA_UserException$methods,
		.instanceof_hash_table=	_jc_org_omg_CORBA_UserException$instanceof_hash_table,
		.class_fields=		&_jc_org_omg_CORBA_UserException$class_fields,
		.num_class_depends=		sizeof(_jc_org_omg_CORBA_UserException$class_depends) / sizeof(*_jc_org_omg_CORBA_UserException$class_depends),
		.class_depends=		_jc_org_omg_CORBA_UserException$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_Throwable= {
	    .fillInStackTrace$6204b72985f9038d=
		&_jc_java_lang_Throwable$method$fillInStackTrace$6204b72985f9038d,
	    .getCause$d5a96efc8523817a=
		&_jc_java_lang_Throwable$method$getCause$d5a96efc8523817a,
	    .getLocalizedMessage$4c1bbba797dccd82=
		&_jc_java_lang_Throwable$method$getLocalizedMessage$4c1bbba797dccd82,
	    .getMessage$13aaf240efc902b1=
		&_jc_java_lang_Throwable$method$getMessage$13aaf240efc902b1,
	    .getStackTrace$566cca4f1a0317f8=
		&_jc_java_lang_Throwable$method$getStackTrace$566cca4f1a0317f8,
	    .initCause$997fed19751e1c64=
		&_jc_java_lang_Throwable$method$initCause$997fed19751e1c64,
	    .printStackTrace$0c533e6284fdc6db=
		&_jc_java_lang_Throwable$method$printStackTrace$0c533e6284fdc6db,
	    .printStackTrace$0235c4ad6dac60e9=
		&_jc_java_lang_Throwable$method$printStackTrace$0235c4ad6dac60e9,
	    .printStackTrace$a53e2b4b86a79644=
		&_jc_java_lang_Throwable$method$printStackTrace$a53e2b4b86a79644,
	    .setStackTrace$a5e8dbdcebe058e2=
		&_jc_java_lang_Throwable$method$setStackTrace$a5e8dbdcebe058e2,
	    .stackTraceString$42eec01c019ee6b0=
		&_jc_java_lang_Throwable$method$stackTraceString$42eec01c019ee6b0,
	    .this$adc93fb6bf4cbffa=
		&_jc_java_lang_Throwable$method$this$adc93fb6bf4cbffa,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	},
	.java_lang_Exception= {
	},
	.org_omg_CORBA_UserException= {
	},
    }
};

==> jc-1.4.6.tar.gz: org/omg/CORBA/UserException.c <==
// public class org.omg.CORBA.UserException

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c25a545561a18c38 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bbafeb7024d20f28 org_omg_CORBA_UserException
// @dep_class f5b7acb90587f314 org_omg_CORBA_portable_IDLEntity

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_omg_CORBA_UserException
// @dep_header org_omg_CORBA_portable_IDLEntity

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/omg/CORBA/UserException.h"
#include "org/omg/CORBA/portable/IDLEntity.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_org_omg_CORBA_UserException$initial_value$serialVersionUID = _JC_JLONG(-6594940734566091244);
static _jc_field _jc_org_omg_CORBA_UserException$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_org_omg_CORBA_UserException$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_org_omg_CORBA_UserException$fields_struct, serialVersionUID),
	.initial_value=	&_jc_org_omg_CORBA_UserException$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_org_omg_CORBA_UserException$fields[] = {
	&_jc_org_omg_CORBA_UserException$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_org_omg_CORBA_UserException$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_org_omg_CORBA_UserException$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_org_omg_CORBA_UserException$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_org_omg_CORBA_UserException$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_omg_CORBA_UserException$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_org_omg_CORBA_UserException$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_omg_CORBA_UserException$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_omg_CORBA_UserException, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_org_omg_CORBA_UserException$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_org_omg_CORBA_UserException$object *this)
{
	struct _jc_org_omg_CORBA_UserException$object *r0;
	struct _jc_java_lang_String$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = _JC_NULL;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	_JC_INVOKE_VIRTUAL(env, java_lang_Throwable, fillInStackTrace$6204b72985f9038d, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r1;
	_JC_LINE_NUMBER(64);				// 0
	return;
}

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_org_omg_CORBA_UserException$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_org_omg_CORBA_UserException$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_org_omg_CORBA_UserException$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_org_omg_CORBA_UserException$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_org_omg_CORBA_UserException$type,
	.param_types=		&_jc_org_omg_CORBA_UserException$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_omg_CORBA_UserException$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_org_omg_CORBA_UserException$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_omg_CORBA_UserException$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_omg_CORBA_UserException, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_org_omg_CORBA_UserException$method$_init$c31b894660454d13(_jc_env *const env, _jc_org_omg_CORBA_UserException$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_org_omg_CORBA_UserException$object *r0;
	struct _jc_java_lang_String$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	_JC_INVOKE_VIRTUAL(env, java_lang_Throwable, fillInStackTrace$6204b72985f9038d, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r1;
	_JC_LINE_NUMBER(73);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_omg_CORBA_UserException$methods[] = {
	&_jc_org_omg_CORBA_UserException$method_info$_init$52f4ad9f2989aeee,
	&_jc_org_omg_CORBA_UserException$method_info$_init$c31b894660454d13
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_org_omg_CORBA_UserException$fields_struct _jc_org_omg_CORBA_UserException$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_omg_CORBA_UserException$interfaces[] = {
	&_jc_org_omg_CORBA_portable_IDLEntity$type,
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_20[] = {
	&_jc_org_omg_CORBA_portable_IDLEntity$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_30[] = {
	&_jc_java_lang_Throwable$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_40[] = {
	&_jc_org_omg_CORBA_UserException$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_87[] = {
	&_jc_java_lang_Exception$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_UserException$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_omg_CORBA_UserException$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_20,
	[30]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_30,
	[40]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_40,
	[65]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_65,
	[87]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_87,
	[101]=	_jc_org_omg_CORBA_UserException$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_omg_CORBA_UserException$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0xc25a545561a18c38) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "org/omg/CORBA/portable/IDLEntity",	_JC_JLONG(0xf5b7acb90587f314) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_omg_CORBA_UserException$vtype _jc_org_omg_CORBA_UserException$type = {
    .type= {
	.name=			"org/omg/CORBA/UserException",
	.superclass=		&_jc_java_lang_Exception$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_omg_CORBA_UserException$interfaces) / sizeof(*_jc_org_omg_CORBA_UserException$interfaces),
	.interfaces=		_jc_org_omg_CORBA_UserException$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		24,
		.hash=			_JC_JLONG(0xbbafeb7024d20f28),
		.source_file=		"UserException.java",
		.instance_size=		sizeof(_jc_org_omg_CORBA_UserException$refs) + sizeof(_jc_org_omg_CORBA_UserException$object),
		.num_virtual_refs=	4,
		.num_fields=		sizeof(_jc_org_omg_CORBA_UserException$fields) / sizeof(*_jc_org_omg_CORBA_UserException$fields),
		.fields=		_jc_org_omg_CORBA_UserException$fields,
		.num_methods=		sizeof(_jc_org_omg_CORBA_UserException$methods) / sizeof(*_jc_org_omg_CORBA_UserException$methods),
		.methods=		_jc_org_omg_CORBA_UserException$methods,
		.instanceof_hash_table=	_jc_org_omg_CORBA_UserException$instanceof_hash_table,
		.class_fields=		&_jc_org_omg_CORBA_UserException$class_fields,
		.num_class_depends=		sizeof(_jc_org_omg_CORBA_UserException$class_depends) / sizeof(*_jc_org_omg_CORBA_UserException$class_depends),
		.class_depends=		_jc_org_omg_CORBA_UserException$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_Throwable= {
	    .fillInStackTrace$6204b72985f9038d=
		&_jc_java_lang_Throwable$method$fillInStackTrace$6204b72985f9038d,
	    .getCause$d5a96efc8523817a=
		&_jc_java_lang_Throwable$method$getCause$d5a96efc8523817a,
	    .getLocalizedMessage$4c1bbba797dccd82=
		&_jc_java_lang_Throwable$method$getLocalizedMessage$4c1bbba797dccd82,
	    .getMessage$13aaf240efc902b1=
		&_jc_java_lang_Throwable$method$getMessage$13aaf240efc902b1,
	    .getStackTrace$566cca4f1a0317f8=
		&_jc_java_lang_Throwable$method$getStackTrace$566cca4f1a0317f8,
	    .initCause$997fed19751e1c64=
		&_jc_java_lang_Throwable$method$initCause$997fed19751e1c64,
	    .printStackTrace$0c533e6284fdc6db=
		&_jc_java_lang_Throwable$method$printStackTrace$0c533e6284fdc6db,
	    .printStackTrace$0235c4ad6dac60e9=
		&_jc_java_lang_Throwable$method$printStackTrace$0235c4ad6dac60e9,
	    .printStackTrace$a53e2b4b86a79644=
		&_jc_java_lang_Throwable$method$printStackTrace$a53e2b4b86a79644,
	    .setStackTrace$a5e8dbdcebe058e2=
		&_jc_java_lang_Throwable$method$setStackTrace$a5e8dbdcebe058e2,
	    .stackTraceString$42eec01c019ee6b0=
		&_jc_java_lang_Throwable$method$stackTraceString$42eec01c019ee6b0,
	    .this$adc93fb6bf4cbffa=
		&_jc_java_lang_Throwable$method$this$adc93fb6bf4cbffa,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	},
	.java_lang_Exception= {
	},
	.org_omg_CORBA_UserException= {
	},
    }
};
